<?php

namespace Smartcat\Includes\Controllers;

use Smartcat\Includes\Requests\AllPostsRequest;
use Smartcat\Includes\Requests\ImportPostsRequest;
use Smartcat\Includes\Requests\PullPostsRequest;
use Smartcat\Includes\Requests\PushPostsRequest;
use Smartcat\Includes\Services\Categories\SmartcatSmartcatCategoriesDatabase;
use Smartcat\Includes\Services\Posts\SmartcatAllPosts;
use Smartcat\Includes\Services\Posts\SmartcatPostsForVerify;
use Smartcat\Includes\Services\Posts\SmartcatPostsImport;
use Smartcat\Includes\Services\Posts\SmartcatPostsDatabase;
use Smartcat\Includes\Services\Posts\SmartcatPostType;
use Smartcat\Includes\Services\Posts\SmartcatPostsPull;
use Smartcat\Includes\Services\Posts\SmartcatPostsPush;
use Smartcat\Includes\Services\Posts\SmartcatPostsWithLocaleTrid;
use Smartcat\Includes\Services\Metadata\SmartcatMetadata;
use Smartcat\Includes\Services\SmartcatWpml;
use Smartcat\Includes\Services\Categories\SmartcatCategoriesImport as CategoriesImportService;
use WP_REST_Request;

class SmartcatPostsController extends Controller
{
    /**
     * @var SmartcatPostsPull
     */
    private $pullService;

    /**
     * @var SmartcatPostsPush
     */
    private $pushService;

    /**
     * @var SmartcatPostsImport
     */
    private $importService;

    /**
     * @var CategoriesImportService
     */
    private $categoriesImportService;

    /**
     * @var SmartcatAllPosts
     */
    private $allPostsService;

    /**
     * @var SmartcatPostsForVerify
     */
    private $verifyPostsService;

    /**
     * @var SmartcatPostsWithLocaleTrid
     */
    private $withLocaleTridService;

    public function __construct()
    {
        $this->pullService = new SmartcatPostsPull(
            new SmartcatPostsDatabase(),
            new SmartcatWpml(),
            new SmartcatMetadata(),
            new SmartcatPostType()
        );
        $this->pushService = new SmartcatPostsPush(
            new SmartcatWpml(),
            new SmartcatMetadata(),
            new SmartcatPostsDatabase()
        );
        $this->importService = new SmartcatPostsImport(
            new SmartcatWpml(),
            new SmartcatPostsDatabase(),
            new SmartcatSmartcatCategoriesDatabase(),
            new SmartcatPostType(),
            new SmartcatMetadata()
        );
        $this->categoriesImportService = new CategoriesImportService(
            new SmartcatWpml(),
            new SmartcatSmartcatCategoriesDatabase()
        );
        $this->allPostsService = new SmartcatAllPosts(
            new SmartcatWpml(),
            new SmartcatPostsDatabase(),
            new SmartcatPostType()
        );
        $this->verifyPostsService = new SmartcatPostsForVerify(
            new SmartcatWpml(),
            new SmartcatPostsDatabase(),
            new SmartcatPostType()
        );
        $this->withLocaleTridService = new SmartcatPostsWithLocaleTrid(
            new SmartcatWpml(),
            new SmartcatPostsDatabase()
        );
    }

    /**
     * @throws \Exception
     */
    public function pull(WP_REST_Request $request): array
    {
        return [
            'lastModifiedDate' => current_time('Y-m-d H:i:s'),
            'posts' => $this->pullService->getPosts(new PullPostsRequest($request))
        ];
    }

    public function push(WP_REST_Request $request): array
    {
        $this->pushService->push(new PushPostsRequest($request));
        return [];
    }

    public function import(WP_REST_Request $request): array
    {
        return [
            'documents' => $this->importService->import(new ImportPostsRequest($request)),
            'categories' => [] // $this->categoriesImportService->import(new ImportPostsRequest($request))
        ];
    }

    public function all(WP_REST_Request $request): array
    {
        return $this->allPostsService->getPosts(new AllPostsRequest($request));
    }

    public function originalPostsForVerify(WP_REST_Request $request): array
    {
        return $this->verifyPostsService->getPosts(new AllPostsRequest($request));
    }

    public function withLocaleTrid(): array
    {
        return $this->withLocaleTridService->getPosts();
    }

    public function translatableTypes(): array
    {
        return [
            'all' => get_post_types(),
            'only_public' => get_post_types(['public' => true,]),
            'smartcat_detected' => smartcat_post_type()->getTranslatableTypes()
        ];
    }
}