<?php

namespace Smartcat\Includes\Tables;

use Smartcat\Includes\Plugin\SmartcatPluginMultilingual as i18n;

require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';

class SmartcatTranslationRequestsTable extends \WP_List_Table
{
    public function column_index($item)
    {
        return $item['index'];
    }

    public function column_translationRequest($item)
    {
        $link = admin_url("/admin.php?page=smartcat-wpml-translation-request");
        $link = add_query_arg('id', $item['id'], $link);
        ?>
        <a href="<?php echo $item['project']['isError'] ? '#' : $link; ?>">
            <?php echo $item['name'] ?>
        </a><p><?php echo implode(', ', $item['posts']) ?></p>
        <?php
    }

    public function column_smartcatProject($item)
    {
        if ($item['project']['isError']) {
            return i18n::_e('Failed to load project');
        }
        ?>
        <a href="<?php echo smartcat_api()::getAuthHost() ?>/projects/<?php echo $item['project']['id'] ?>" target="_blank"> <span class="dashicons dashicons-admin-links"></span>
            <?php echo $item['project']['name'] ?>
        </a>
        <?php
    }

    public function column_status($item)
    {
        if ($item['status']['type'] === 'error') {
            ?>
            <p style="color: red;">
                <?php i18n::e('We were unable to load the Smartcat project. Make sure your account has access to it.') ?>
            </p>
            <?php
        } else {
            echo $item['status']['type'] . ' ';
            echo $item['status']['type'] === i18n::_e('In progress') ? "({$item['status']['progress']}%)" : '';
        }
    }

    public function column_sourceLanguage($item)
    {
        return $item['languages']['source'];
    }

    public function column_targetLanguages($item)
    {
        echo implode(', ', $item['languages']['target']);
    }

    public function column_deadline($item)
    {
        if (empty($item['project']['deadline'])) {
            return i18n::_e('Not set');
        }
        $deadline = new \DateTime($item['project']['deadline']);
        return $deadline->format('Y/m/d H:i:s');
    }

    public function column_comment($item)
    {
        echo $item['comment'] ?? '-';
    }

    public function column_action($item)
    {
        ?>
        <div style="display: flex; align-items: center; justify-content: flex-end;">
            <div class="smartcat-spin" style="display: none" id="smartcat-spin-<?php echo $item['id'] ?>">
                <span class="dashicons dashicons-update"></span>
            </div>
        </div>
        <div class="smartcat-dropdown-menu" id="smartcat-actions-<?php echo $item['id'] ?>">
            <span class="smartcat-dropdown-menu-title"><?php i18n::e('Actions') ?> <span class="dashicons dashicons-arrow-down-alt2"></span></span>
            <div class="smartcat-dropdown-menu-actions">
                <?php
                if (!$item['project']['isError']) {
                    ?>
                    <a href="#" class="smartcat-dropdown-menu-actions_item smartcat-get-translations-from-dashboard" smartcat-tr-id="<?php echo $item['id'] ?>"><?php i18n::e('Get translations') ?></a>
                    <?php
                }
                ?>
                <a href="#" style="color: #b32d2e;" class="smartcat-dropdown-menu-actions_item red smartcat-delete-tr-button" smartcat-tr-id="<?php echo $item['id'] ?>"><?php i18n::e('Delete translation request') ?></a>
            </div>
        </div>
        <?php
    }

    public function prepare_items()
    {
        $translationRequests = smartcat_dm()->getTranslationRequests();
        $this->items = $translationRequests['items'];
        $this->_column_headers = [$this->get_columns()];
    }

    public function get_columns(): array
    {
        return [
            'index' => '№',
            'translationRequest' => i18n::_e('Translation request'),
            'smartcatProject' => i18n::_e('Smartcat project'),
            'status' => i18n::_e('Status'),
            'sourceLanguage' => i18n::_e('Source language'),
            'targetLanguages' => i18n::_e('Target languages'),
            'comment' => i18n::_e('Comment'),
            'deadline' => i18n::_e('Deadline'),
            'action' => ''
        ];
    }

    protected function column_default($item, $column_name)
    {
        switch ($column_name) {
            default:
                return 'no value';
        }
    }

    public function single_row($item)
    {
        $cssClass = $item['project']['isError'] ? 'smartcat__error-row' : '';
        echo '<tr class="' . $cssClass . '">';
        $this->single_row_columns($item);
        echo '</tr>';
    }
}