<?php

namespace Smartcat\Includes\Templates;

use Smartcat\Includes\Plugin\SmartcatPluginMultilingual as i18n;

class SmartcatCreateTrPage
{
    public static function renderTargetLanguages($sourceLanguageCode)
    {
        ?>
        <table width="100%" id="icl_untranslated_table" class="icl_translations_table">
            <tbody>
            <tr>
                <th align="left"><?php esc_html_e('Language', 'sitepress') ?></th>
                <th align="right"><?php esc_html_e('Translate', 'sitepress') ?></th>
            </tr>
            <?php
            self::renderLanguageRows($sourceLanguageCode);
            ?>
            </tbody>
        </table>
        <?php
    }

    private static function renderLanguageRows($sourceLanguageCode)
    {
        foreach (smartcat_wpml()->getActiveLanguages() as $activeLanguage) {
            if ($activeLanguage['code'] === $sourceLanguageCode) {
                continue;
            }
            ?>
            <tr class="icl_odd_row">
                <td style="padding-left: 4px;">
                    <label for="<?php echo $activeLanguage['language_code'] ?>">
                        <?php echo $activeLanguage['translated_name'] ?>
                    </label>
                </td>
                <td align="right">
                    <input type="checkbox" class="language smartcat-language" id="<?php echo $activeLanguage['language_code'] ?>" name="smartcat_languages[]" value="<?php echo $activeLanguage['language_code'] ?>">
                </td>
            </tr>
            <?php
        }
    }

    public static function renderProjectsSelector($postId)
    {
        ?>
        <label class="wp-caption-text" style="display: block;margin-top: 10px;" for="">
            <?php i18n::e('Smartcat project'); ?>
        </label>

        <?php
        $projects = smartcat_api()->getAccountProjects();
        if (is_wp_error($projects)) {
            $projects->showError();
        } else {
            self::renderProjectOptions($projects, smartcat_wpml()->getPostLanguageCode($postId));
        }
        ?><?php
    }

    private static function renderProjectOptions($projects, $lang)
    {
        ?>
        <select name="projects-list" id="projects-list" style="margin: 10px 0; width: 100%">
            <option value="new" selected>New</option>
            <?php
            $projects = array_filter($projects, function ($p) use ($lang) {
                return $p['sourceLanguage'] === $lang;
            });
            foreach ($projects as $project) {
                echo "<option source-lang='{$project['sourceLanguage']}' target-langs='" . json_encode($project['targetLanguages']) . "' value='{$project['id']}'>{$project['name']}</option>";
            }
            ?>
        </select>
        <?php
    }

    public static function renderHiddenInputs($postId, $postIds)
    {
        ?>
        <input type="hidden" id="post-id" value="<?php echo json_encode($postIds) ?>">
        <input type="hidden" id="source-lang" value="<?php echo smartcat_wpml()->getPostLanguageCode($postId) ?>">
        <?php
    }

    public static function renderSettingsHeader($sourceLanguageName)
    {
        ?>
        <h3><?php echo __('Settings', 'smartcat-wpml') ?></h3>
        <p>
            <?php echo __('Source lang:', 'smartcat-wpml') ?> <b><?php echo $sourceLanguageName; ?></b>
        </p>
        <?php
    }

    public static function renderSendButton()
    {
        ?>
        <button id="create-translation" style="margin-top: 10px;" class="button button-primary" disabled>
            <?php i18n::e('Send to Smartcat'); ?>
        </button>
        <?php
    }
}