<?php

namespace Smartcat\Includes\Templates;

use Smartcat\Includes\Plugin\SmartcatPluginMultilingual as i18n;

class SmartcatMetaboxSendForm
{
    private static $translationRequestId;
    private static $postId;
    private static $smartcatProjectId;
    private static $sourceLanguage;
    private static $sourceLanguageCode;

    public static function init($postId, $hasTranslationRequest)
    {
        self::$postId = $postId;
        if ($hasTranslationRequest) {
            self::$translationRequestId = smartcat_dm()->getTranslationRequestId(self::$postId);
            self::$smartcatProjectId = smartcat_dm()->getPostProjectId(self::$postId, self::$translationRequestId);
        }
        self::$sourceLanguage = smartcat_wpml()->getPostLanguageName($postId);
        self::$sourceLanguageCode = smartcat_wpml()->getPostLanguageCode($postId);
    }

    public static function renderTrIdInput()
    {
        ?>
        <input id="smartcat-tr-id" type="hidden" value="<?php echo self::$translationRequestId ?>">
        <?php
    }

    public static function renderDeadlineInput()
    {
        ?>
         <label class="wp-caption-text" style="display: block;margin-top: 10px;" for="smartcat-deadline-input">
            <?php i18n::e('Deadline'); ?>
        </label>
        <input
            type="datetime-local"
            id="smartcat-deadline-input"
            style="display: block; margin: 10px 0;"
        >
        <?php
        self::renderDeadlineWarn();
    }

    public static function renderCommentInput()
    {
        ?>
         <label class="wp-caption-text" style="display: block;margin-top: 10px;" for="smartcat-comment-input">
            <?php i18n::e('Comment'); ?>
        </label>
        <textarea
            placeholder="<?php i18n::e('Example: Read the following style guide before translat...'); ?>"
            id="smartcat-comment-input"
            style="display: block; margin: 10px 0; width: 100%;"
        ></textarea>
        <?php
        self::renderDeadlineWarn();
    }

    public static function renderPopups()
    {
        ?>
        <div id="smartcat-remove-lang-popup" class="smartcat-popup-wrapper">
            <div class="smartcat-popup">
                <input type="hidden" class="smartcat-popup-value">
                <p class="smartcat-popup-title"></p>
                <div class="smartcat-popup-buttons">
                    <button class="button cancel">Cancel</button>
                    <button class="button button-primary confirm">Yes</button>
                </div>
            </div>
        </div>
        <div id="smartcat-add-lang-popup" class="smartcat-popup-wrapper">
            <div class="smartcat-popup">
                <input type="hidden" class="smartcat-popup-value">
                <p class="smartcat-popup-title"></p>
                <div class="smartcat-popup-buttons">
                    <button class="button cancel">Cancel</button>
                    <button class="button button-primary confirm">Yes</button>
                </div>
            </div>
        </div>
        <?php
    }

    public static function renderSmartcatProjectLink()
    {
        ?>
        <input type="hidden" id="smartcat-project-id" value="<?php echo self::$smartcatProjectId ?>">
        <a style="display:block; margin: 10px 0" target="_blank" href="<?php echo smartcat_api()::getAuthHost() ?>/projects/<?php echo self::$smartcatProjectId ?>/files">
            <?php i18n::e('Go to Smartcat project'); ?>
        </a>
        <?php
    }

    public static function renderSmartcatProjectDeadline()
    {
        $project = smartcat_hub_client()->getProject(
            self::$smartcatProjectId,
            self::$sourceLanguageCode
        );
        ?>
        <p><?php i18n::e('Deadline'); ?>: <i><?php
            $deadline = isset($project['deadline']) ? new \DateTime($project['deadline']) : NULL;
            echo !empty($deadline) ? $deadline->format('Y/m/d H:i:s') : i18n::_e('Not set')
        ?></i></p>
        <?php
    }

    public static function renderLanguagesTableWithTranslationRequest()
    {
        ?>
        <table width="100%" id="icl_untranslated_table" class="icl_translations_table">
            <tbody>
            <tr>
                <th align="left"><?php esc_html_e('Language', 'sitepress') ?></th>
                <th align="right"><?php esc_html_e('Translate', 'sitepress') ?></th>
                <th align="right"><?php esc_html_e('Progress', 'sitepress') ?></th>
            </tr>
            <?php
              self::renderActiveLanguagesJoinDocuments();
            ?>
            </tbody>
        </table>
        <?php
    }

    public static function renderActiveLanguagesJoinDocuments()
    {
        $documents = smartcat_dm()->getPostDocuments(self::$postId);
        foreach (smartcat_wpml()->getActiveLanguages() as $activeLanguage) {
            if ($activeLanguage['active'] === '1') {
                continue;
            }

            $document = array_filter($documents, function ($d) use ($activeLanguage) {
                return $d->lang === $activeLanguage['language_code'];
            });

            $document = array_shift($document);
            ?>
            <tr class="<?php echo !empty($document) ? 'icl_odd_row' : '' ?>">
                <td style="padding-left: 4px;">
                    <label for="<?php echo $activeLanguage['language_code'] ?>">
                        <?php echo $activeLanguage['translated_name'] ?>
                    </label>
                </td>
                <td align="right">
                    <input
                        type="checkbox"
                        class="language-with-tr"
                        in-request="<?php echo !empty($document) ? 'true' : 'false' ?>"
                        id="<?php echo $activeLanguage['language_code'] ?>"
                        language-name="<?php echo $activeLanguage['translated_name'] ?>"
                        name="smartcat_languages[]"
                        value="<?php echo $activeLanguage['language_code'] ?>"
                        <?php echo !empty($document) ? 'checked' : '' ?>
                    >
                </td>
                <td align="right" style="padding-right: 10px;"><?php echo !empty($document) ? $document->translation_progress . '%' : '' ?></td>
                <?php
                    if (!empty($document)) {
                        $hasTranslatedPost = !is_null($document->translated_post_id);
                        ?>
                        <td align="right" style="padding-right: 10px;">
                            <div class="smartcat-dropdown-menu">
                                <span class="smartcat-dropdown-menu-title">Actions <span class="dashicons dashicons-arrow-down-alt2"></span></span>
                                <div class="smartcat-dropdown-menu-actions">
                                    <a
                                        href="<?php echo self::getSmartcatDocumentLink($document->smartcat_document_id) ?>"
                                        class="smartcat-dropdown-menu-actions_item"
                                        target="_blank"
                                    ><?php i18n::e('Edit in Smartcat'); ?></a>
                                    <a
                                        href="<?php echo $hasTranslatedPost ? get_edit_post_link($document->translated_post_id) : '#' ?>"
                                        class="smartcat-dropdown-menu-actions_item <?php echo !$hasTranslatedPost ? 'disabled' : '' ?>"
                                        target="_blank"
                                    ><?php i18n::e('Edit in Wordpress'); ?></a>
                                </div>
                            </div>
                        </td>
                        <?php
                    }
                ?>
            </tr>
            <?php
        }
    }

    public static function renderDeadlineWarn()
    {
        ?>
        <p id="smarcat-deadline-warn" class="notice notice-warning" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <?php
    }

    public static function renderErrorNotice()
    {
        ?>
        <p id="error-project" class="notice notice-error" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <?php
    }

    public static function renderSuccessNotice()
    {
        ?>
        <p id="smartcat-success-notice" class="notice notice-success" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <?php
    }

    public static function renderHiddenInputs()
    {
        ?>
        <input type="hidden" id="post-id" value="<?php echo self::$postId ?>">
        <input type="hidden" id="source-lang" value="<?php echo self::$sourceLanguageCode ?>">
        <?php
    }

    public static function renderSendButton()
    {
        ?>
        <button id="create-translation" style="margin-top: 10px;" class="button button-primary smartcat-button" disabled>
            <span class="dashicons dashicons-update"></span>
            <?php i18n::e('Send to Smartcat'); ?>
        </button>
        <?php
    }

    public static function renderGetButton()
    {
        ?>
        <button id="get-translations" style="margin-top: 10px;" class="button button-secondary smartcat-button">
            <span class="dashicons dashicons-update"></span>
            <?php i18n::e('Get from Smartcat'); ?>
        </button>
        <?php
    }

    public static function renderProjectsSelector()
    {
        ?>
        <label class="wp-caption-text" style="display: block; margin-top: 10px;" for="">
            <?php i18n::e('Smartcat project'); ?>
        </label>

        <div>
        <?php
        $projects = smartcat_api()->getAccountProjects();
        if (is_wp_error($projects)) {
            $projects->showError();
        } else {
            self::renderProjectOptions($projects, smartcat_wpml()->getPostLanguageCode(self::$postId));
        }
        ?>
        <?php
    }

    public static function renderHeader()
    {
        ?>
        <label class="wp-caption-text" for="source_language">
            <?php i18n::e('Source language'); ?>: <b><?php echo self::$sourceLanguage ?></b>
            </label>

        <label class="wp-caption-text" style="display: block; margin-top: 10px;margin-bottom: 10px;" for="target_languages">
            <?php i18n::e('Target languages'); ?>
        </label>
        <?php
    }

    public static function renderLanguagesTableWithoutTranslationRequest()
    {
        ?>
        <table width="100%" id="icl_untranslated_table" class="icl_translations_table">
            <tbody>
            <tr>
                <th align="left"><?php esc_html_e('Language', 'sitepress') ?></th>
                <th align="right"><?php esc_html_e('Translate', 'sitepress') ?></th>
            </tr>
            <?php
            self::renderActiveLanguagesRows();
            ?>
            </tbody>
        </table>
        <?php
    }

    public static function renderActiveLanguagesRows()
    {
        foreach (smartcat_wpml()->getActiveLanguages() as $activeLanguage) {
            if ($activeLanguage['active'] === '1') {
                continue;
            }
            ?>
            <tr class="icl_odd_row">
                <td style="padding-left: 4px;">
                    <label for="<?php echo $activeLanguage['language_code'] ?>">
                        <?php echo $activeLanguage['translated_name'] ?>
                    </label>
                </td>
                <td align="right">
                    <input type="checkbox" class="language smartcat-language" id="<?php echo $activeLanguage['language_code'] ?>" name="smartcat_languages[]" value="<?php echo $activeLanguage['language_code'] ?>">
                </td>
            </tr>
            <?php
        }
    }

    public static function renderProjectOptions($projects, $lang)
    {
        ?>
        <select name="projects-list" id="projects-list" style="margin: 10px 0; width: 100%">
            <option value="new" selected><?php i18n::e('New project'); ?></option>
            <?php
            $projects = array_filter($projects, function ($p) use ($lang) {
                return $p['sourceLanguage'] === $lang;
            });
            foreach ($projects as $project) {
                ?>
                <option
                    source-lang="<?php echo $project['sourceLanguage'] ?>"
                    target-langs='<?php echo json_encode($project['targetLanguages']) ?>'
                    deadline="<?php echo $project['deadline'] ?? '' ?>"
                    value="<?php echo $project['id'] ?>"
                    ><?php echo $project['name']; ?></option>
                <?php
            }
            ?>
        </select>
        <?php
    }

    private static function getSmartcatDocumentLink($documentId): string
    {
        $split = explode('_', $documentId);
        $id = $split[0];
        $lang = $split[1];
        return smartcat_api()::getAuthHost() . "/editor?documentId=$id&languageId=$lang";
    }
}