<?php

namespace Smartcat\Includes\Templates;

use Smartcat\Includes\Services\TranslationRequest\SmartcatTranslationRequest;
use Smartcat\Includes\Plugin\SmartcatPluginMultilingual as i18n;

class SmartcatTrDetailsPage
{
    /** @var SmartcatTranslationRequest $tr */
    private static $tr;
    private static $sourceLanguageCode;
    private static $targetLanguages;
    private static $smartcatProject;

    public static function init($trId)
    {
        self::$tr = new SmartcatTranslationRequest($trId);
        self::$sourceLanguageCode = self::$tr->getSourceLanguageCode();
        $wpmlActiveLanaguages = smartcat_wpml()->getActiveLanguages();
        self::$targetLanguages = array_filter($wpmlActiveLanaguages, function ($lang) {
            return $lang['code'] !== self::$sourceLanguageCode;
        });
        self::$smartcatProject = smartcat_hub_client()->getProject(
                self::$tr->getProjectId(),
                self::$tr->getSourceLanguageCode()
        );
    }

    public static function table()
    {
        ?>
        <table class="smartcat-table">
            <?php self::tableHead(); ?>
            <tbody>
            <?php
            foreach (self::$tr->getPostIds() as $id) {
                self::tableItem(get_post($id));
            }
            ?>
            </tbody>
        </table>
        <?php
    }

    private static function tableHead()
    {
        ?>
        <thead>
        <tr>
            <th><?php i18n::e('Post/Page'); ?></th>
            <?php
            foreach (self::$targetLanguages as $targetLanguage) {
                ?>
                <th>
                    <?php echo $targetLanguage['translated_name'] ?>
                </th>
                <?php
            }
            ?>
            <th></th>
        </tr>
        </thead>
        <?php
    }

    private static function tableItem($post)
    {
        ?>
        <tr>
            <td><a href="<?php echo get_edit_post_link($post->ID) ?>" target="_blank"><?php echo $post->post_title ?></a></td>
            <?php
            foreach (self::$targetLanguages as $targetLanguage) {
                //  echo $targetLanguage['translated_name']
                ?>
                <td>
                    <input type="checkbox" class="smartcat-language" post-id="<?php echo $post->ID ?>" value="<?php echo $targetLanguage['code'] ?>" language-name="<?php echo $targetLanguage['translated_name'] ?>" in-request="<?php echo self::$tr->postHasTranslatedLang($post->ID, $targetLanguage['code']) ? 'true' : 'false' ?>"
                        <?php echo self::$tr->postHasTranslatedLang($post->ID, $targetLanguage['code']) ? 'checked' : '' ?>
                    >
                </td>
                <?php
            }
            ?>
            <td>
                <div style="display: flex; align-items: center; justify-content: flex-end;">
                    <div class="smartcat-spin" style="display: none" id="smartcat-spin-<?php echo $post->ID ?>">
                        <span class="dashicons dashicons-update"></span>
                    </div>
                </div>
                <div class="smartcat-dropdown-menu" id="smartcat-dropdown-menu-<?php echo $post->ID ?>">
                    <span class="smartcat-dropdown-menu-title"><?php i18n::e('Actions'); ?> <span class="dashicons dashicons-arrow-down-alt2"></span></span>
                    <div class="smartcat-dropdown-menu-actions">
                        <a href="#" class="smartcat-dropdown-menu-actions_item smartcat-get-translations-action" post-id="<?php echo $post->ID ?>"><?php i18n::e('Get translations'); ?></a>
                        <a href="#" class="smartcat-dropdown-menu-actions_item smartcat-remove-post-action" post-id="<?php echo $post->ID ?>"><?php i18n::e('Remove'); ?></a>
                    </div>
                </div>
            </td>
        </tr>
        <?php
    }

    public static function name()
    {
        echo self::$tr->getName();
    }

    public static function smartcatProjectLink()
    {
        ?>
        <p style="display: flex;">
            <?php i18n::e('Smartcat project'); ?>: <a style="display:block; margin-left: 5px;" href="<?php echo self::getSmartcatProjectLink() ?>"><?php echo self::$smartcatProject['name'] ?></a>
        </p>
        <?php
    }

    private static function getSmartcatProjectLink()
    {
        return smartcat_api()::getAuthHost() . '/projects/ ' . self::$smartcatProject['id'] . ' /files';
    }

    public static function deadline()
    {
        $deadline = new \DateTime(self::$smartcatProject['deadline']);
        ?>
        <p><?php i18n::e('Deadline'); ?>: <b><?php echo $deadline->format('Y/m/d H:i:s') ?></b></p>
        <?php
    }

    public static function translatedPostsTotal()
    {
        ?>
        <p><?php i18n::e('Posts total'); ?>: <?php echo count(self::$tr->getPostIds()) ?></p>
        <?php
    }

    public static function popups()
    {
        ?>
        <div id="smartcat-remove-post-from-tr" class="smartcat-popup-wrapper">
            <div class="smartcat-popup">
                <input type="hidden" class="smartcat-popup-value">
                <p class="smartcat-popup-title"><?php i18n::e('Are you sure you want to remove this post from the translation request?'); ?></p>
                <div class="smartcat-popup-buttons">
                    <button class="button cancel"><?php i18n::e('Cancel'); ?></button>
                    <button class="button button-primary confirm smartcat-button">
                        <span class="dashicons dashicons-update"></span>
                        <?php i18n::e('Yes'); ?>
                    </button>
                </div>
            </div>
        </div>
        <div id="smartcat-add-lang-to-post" class="smartcat-popup-wrapper">
            <div class="smartcat-popup">
                <input type="hidden" class="smartcat-popup-value">
                <input type="hidden" class="smartcat-popup-value-post-id">
                <p class="smartcat-popup-title"></p>
                <div class="smartcat-popup-buttons">
                    <button class="button cancel"><?php i18n::e('Cancel'); ?></button>
                    <button class="button button-primary confirm smartcat-button">
                        <span class="dashicons dashicons-update"></span>
                        <?php i18n::e('Yes'); ?>
                    </button>
                </div>
            </div>
        </div>
        <div id="smartcat-remove-post-lang" class="smartcat-popup-wrapper">
            <div class="smartcat-popup">
                <input type="hidden" class="smartcat-popup-value">
                <input type="hidden" class="smartcat-popup-value-post-id">
                <p class="smartcat-popup-title"></p>
                <div class="smartcat-popup-buttons">
                    <button class="button cancel"><?php i18n::e('Cancel'); ?></button>
                    <button class="button button-primary confirm smartcat-button">
                        <span class="dashicons dashicons-update"></span>
                        <?php i18n::e('Yes'); ?>
                    </button>
                </div>
            </div>
        </div>
        <?php
    }

    public static function hiddenInputs()
    {
        ?>
        <input type="hidden" name="smartcat-tr-id" value="<?php echo self::$tr->getId() ?>">
        <?php
    }

    public static function notices()
    {
        ?>
        <p id="smarcat-tr-details-info" class="notice notice-info" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <p id="smarcat-tr-details-error" class="notice notice-danger" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <p id="smarcat-tr-details-success" class="notice notice-success" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <p id="smarcat-tr-details-warn" class="notice notice-warning" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <?php
    }
}