<?php

namespace Smartcat\Includes\Views;

use Smartcat\Includes\Services\Smartcat\SmartcatClient;
use Smartcat\Includes\Services\Tools\SmartcatNotice;
use Smartcat\Includes\Services\TranslationRequest\SmartcatTranslationRequest;
use Smartcat\Includes\Plugin\SmartcatPluginMultilingual as i18n;

class SmartcatMetabox
{
    private $components;
    private $postId;
    private $sourceLanguageName;
    private $sourceLanguageCode;
    private $hasTranslationRequest;
    private $translationRequestId = NULL;
    private $translationRequest;
    private $project;

    public function __construct($postId)
    {
        $this->components = new SmartcatComponents();
        $this->postId = $postId;
        $this->hasTranslationRequest = smartcat_dm()->hasTranslationRequest($postId);
        $this->sourceLanguageName = smartcat_wpml()->getPostLanguageName($postId);
        $this->sourceLanguageCode = smartcat_wpml()->getPostLanguageCode($postId);
        if ($this->hasTranslationRequest) {
            $this->translationRequestId = smartcat_dm()->getTranslationRequestId($postId);
            $this->translationRequest = new SmartcatTranslationRequest($this->translationRequestId);
            $this->project = smartcat_hub_client()->getProject(
                $this->translationRequest->getProjectId(),
                $this->translationRequest->getSourceLanguageCode()
            );
        }
    }

    public function display()
    {
        if (is_null($this->sourceLanguageCode)) {
            echo 'Finish creating an article to send for translation';
            return;
        }

        if (SmartcatClient::isAuthorized()) {
            $this->components->hiddenInputs($this->sourceLanguageCode, $this->postId, $this->translationRequestId);
            $this->components->sourceLanguage($this->sourceLanguageName);

            if ($this->hasTranslationRequest) {
                if (is_wp_error($this->project)) {
                    $this->errorProject();
                    return;
                }
                smartcat_dm()->updateDocumentsProgress($this->postId);
                $this->components->languagesTableWithTranslations($this->postId);
                $this->components->projectDeadline($this->project['deadline'] ?? NULL);
                $this->components->projectLink($this->project['id'], $this->project['name']);
                $this->components->startButtonGroup();
                $this->components->getTranslationsButton();
                $this->components->updateSourceButton();
                $this->components->endButtonGroup();
            } else {
                $this->components->languagesTable();
                $this->components->projectsSelector($this->sourceLanguageCode);
                $this->components->deadlineInput();
                $this->components->commentInput();
                $this->components->sendToSmartcatButton();
            }
            $this->components->notices();
            $this->components->popup();
        } else {
            $this->unauthorizedNotice();
        }
    }

    private function errorProject()
    {
        ?>
        <p style="color:red;"><?php i18n::e('This post is found in a translation request whose project could not be uploaded. Your account may not have access. Authorize your account and try again or delete the translation request.') ?></p>
        <?php
    }

    private function unauthorizedNotice()
    {

        ?>
        <p>
            Log in to Smartcat in <a href="<?php echo admin_url("/admin.php?page=smartcat-wpml") ?>">settings</a>.
        </p>
        <?php
    }
}