<?php

namespace Smartcat\Includes\Views;

use Smartcat\Includes\Services\Tools\SmartcatNotice;
use Smartcat\Includes\Services\TranslationRequest\SmartcatTranslationRequest;
use Smartcat\Includes\Tables\SmartcatTranslationRequestPosts;

class SmartcatTranslationRequestDetails
{
    private $components;
    private $translationRequestId;

    public function __construct()
    {
        $this->components = new SmartcatComponents();
        $this->translationRequestId = $_GET['id'] ?? NULL;
    }

    public function display()
    {
        $this->components->startWrapper('60%', 'tr-details');
        if (smartcat_dm()->translationRequestExists($this->translationRequestId)) {
            $translationRequest = new SmartcatTranslationRequest($this->translationRequestId);
            $this->components->hiddenInputs($translationRequest->getSourceLanguageCode(), NULL, $translationRequest->getId());
            $project = smartcat_hub_client()->getProject($translationRequest->getProjectId(), $translationRequest->getSourceLanguageCode());
            if (is_wp_error($project)) {
                $project->showError();
                return;
            }
            $this->components->title("{$translationRequest->getName()} - details");
            $this->components->projectLink($translationRequest->getProjectId(), $project['name']);
            $this->components->projectDeadline($project['deadline'] ?? NULL);
            $table = new SmartcatTranslationRequestPosts();
            $table->setSourceLanguage($translationRequest->getSourceLanguageCode());
            $table->setTranslationRequest($translationRequest);
            $table->prepare_items();
            $this->components->notices();
            $table->display();
            $this->components->popup();
        } else {
            SmartcatNotice::notice('error', 'Translation request not found.');
        }
        $this->components->endWrapper();
    }
}