<?php

use Smartcat\Includes\Services\Posts\SmartcatImportTranslations;
use Smartcat\Includes\Services\Posts\SmartcatPostsDatabase;
use Smartcat\Includes\Services\Posts\SmartcatPostType;
use Smartcat\Includes\Services\Smartcat\SmartcatSmartcatHubClient;
use Smartcat\Includes\Services\Metabox\SmartcatMetabox;
use Smartcat\Includes\Services\Tools\SmartcatNotice;
use Smartcat\Includes\Services\Plugin\SmartcatSettings;
use Smartcat\Includes\Services\Smartcat\SmartcatClient;
use Smartcat\Includes\Services\TranslationRequest\SmartcatDocumentsManager;
use Smartcat\Includes\Services\SmartcatWpml;
use Smartcat\Includes\Services\Metadata\SmartcatMetadata;
use Smartcat\Includes\Plugin\SmartcatPluginMultilingual as i18n;
use Smartcat\Includes\Views\SmartcatCreateTranslationRequest;
use Smartcat\Includes\Views\SmartcatDashboard;
use Smartcat\Includes\Views\SmartcatLogs;
use Smartcat\Includes\Views\SmartcatTranslationRequestDetails;
use PHPHtmlParser\Dom;

class SmartcatAdmin
{
    private $pluginName;
    private $version;

    /**
     * @var SmartcatSettings
     */
    private $settings;

    /** @var SmartcatMetabox */
    private $metaboxService;

    /** @var SmartcatPostType */
    private $postTypesService;

    public function __construct($pluginName, $version)
    {
        $this->pluginName = $pluginName;
        $this->version = $version;
        $this->settings = new SmartcatSettings();
        $this->metaboxService = new SmartcatMetabox(
            new SmartcatClient(),
            new SmartcatSmartcatHubClient(),
            new SmartcatDocumentsManager(),
            new SmartcatImportTranslations(
                new SmartcatWpml(),
                new SmartcatMetadata(),
                new SmartcatPostsDatabase()
            ),
            new SmartcatMetadata()
        );
        $this->postTypesService = new SmartcatPostType();

        new SmartcatClient();
    }

    public function enqueue_styles()
    {
        wp_enqueue_style( 'wp-jquery-ui-dialog' );
        wp_enqueue_style($this->pluginName, plugin_dir_url(__FILE__) . 'assets/css/smartcat-wpml.css', [], $this->version);
    }

    public function enqueue_scripts()
    {
        wp_enqueue_script( 'jquery-ui-dialog' );
        wp_enqueue_script($this->pluginName, plugin_dir_url(__FILE__) . 'assets/js/smartcat-wpml.js', array('jquery'), $this->version, true);
    }

    public function handleBulkActionSmartcatCreateTR($redirectTo, $doAction, $postIds)
    {
        if ($doAction !== SMARTCAT_CREATE_TRANSLATION_BULK_ACTION) {
            return $redirectTo;
        }
        $redirectTo = admin_url("/admin.php?page=$this->pluginName-create-translation-request");
        $redirectTo = add_query_arg('posts', json_encode($postIds), $redirectTo);
        wp_redirect($redirectTo);
    }

    public function addBulkActionToPostsPage($bulkActions)
    {
        $bulkActions[SMARTCAT_CREATE_TRANSLATION_BULK_ACTION] = 'Translate selected posts';
        return $bulkActions;
    }

    public function logInToSmartcat()
    {
        $this->metaboxService->logInToSmartcat();
    }

    public function registerSmartcatMetabox()
    {
        add_meta_box(
            'smartcat_metabox',
            'Smartcat',
            [$this->metaboxService, 'displayForm'],
            $this->postTypesService->getTranslatableTypes(),
            'side',
            'high'
        );
    }

    public function addPluginAdminMenu()
    {
        add_menu_page(
            'Smartcat Integration for WPML',
            'Smartcat',
            'edit_others_posts',
            $this->pluginName,
            [$this, 'displayPluginSettingsPage'],
            plugin_dir_url(__FILE__) . 'assets/img/icon.svg'
        );
        add_submenu_page(
            $this->pluginName,
            'Smartcat Integration for WPML',
            i18n::_e('Settings'),
            'manage_options',
            $this->pluginName,
            [$this, 'displayPluginSettingsPage']
        );
        add_submenu_page(
            $this->pluginName,
            'Smartcat Integration for WPML',
            i18n::_e('Translation requests'),
            'manage_options',
            "$this->pluginName-dashboard",
            [$this, 'displayTranslationRequestsDashboard']
        );
        add_submenu_page(
            "$this->pluginName-hidden",
            'Smartcat Integration for WPML',
            i18n::_e('Create translation request'),
            'manage_options',
            "$this->pluginName-create-translation-request",
            [$this, 'displayCreateTranslationRequestPage']
        );
        add_submenu_page(
            "$this->pluginName-hidden",
            'Smartcat Integration for WPML',
            i18n::_e('Transaltion request details'),
            'manage_options',
            "$this->pluginName-translation-request",
            [$this, 'displayTranslationRequestDetailsPage']
        );
        add_submenu_page(
            "$this->pluginName-hidden",
            'Smartcat Integration for WPML',
            i18n::_e('Smartcat event log'),
            'manage_options',
            "$this->pluginName-logs",
            [$this, 'displayLogsPage']
        );
    }

    public function checkOrUpdateMigrations()
    {
        (new \Smartcat\Includes\Services\Plugin\SmartcatMigrations())->run();
    }

    public function deleteTranslation($postId)
    {
        smartcat_dm()->removePost($postId);
    }

    public function addActionLinks($links): array
    {
        $customLinks = [
            '<a href="' . admin_url('options-general.php?page=' . $this->pluginName) . '">' . __('Settings', $this->pluginName) . '</a>'
        ];
        return array_merge($customLinks, $links);
    }

    public function displayPluginSettingsPage()
    {
        if ($_SERVER["REQUEST_METHOD"] === "POST") {
            if (isset($_POST["_type"])) {
                switch ($_POST["_type"]) {
                    case "security":
                        // $this->updateSecurity($_POST);
                        break;
                }
            }
        }
        include_once('pages/settings.php');
        unset($_POST["smartcat_message"]);
        unset($_POST["smartcat_message_type"]);
    }

    public function displayTranslationRequestsDashboard()
    {
        (new SmartcatDashboard())->display();
    }

    public function displayCreateTranslationRequestPage()
    {
        (new SmartcatCreateTranslationRequest())->display();
    }

    public function displayTranslationRequestDetailsPage()
    {
        (new SmartcatTranslationRequestDetails())->display();
    }

    public function displayLogsPage()
    {
        (new SmartcatLogs())->display();
    }

    /**
     * @return void
     */
    public function smartcatUpdateOptions()
    {
        $this->settings->options($this->pluginName);
    }

    public function smartcatLogout()
    {
        $this->settings->smartcatLogout($this->pluginName);
    }

    public function updateDebugSettings()
    {
        $this->settings->updateDebugSettings($this->pluginName);
    }

    /**
     * @return void
     */
    public function displayPluginAdminNotices()
    {
        $noticeStatus = sanitize_text_field($_REQUEST['smartcat_notice_status'] ?? NULL);
        if (!empty($noticeStatus)) {
            $noticeContent = sanitize_text_field($_REQUEST['smartcat_notice_content']);
            SmartcatNotice::notice($noticeStatus, $noticeContent);
        }
    }

    /**
     * @return void
     */
    public function displayWpmlNotInstalledNotice()
    {
        SmartcatNotice::error('WPML plugin is not installed or activated. Smartcat Integration Add-on is not active');
    }

    /**
     * @return void
     */
    public function displayFriendlyUrlNotice()
    {
        SmartcatNotice::error("The site uses simple links without a Friendly URL. Activate Friendly URL for Smartcat Integration Add-on to work correctly. <a href='https://wordpress.org/support/article/using-permalinks/' target='_blank'>More</a>");
    }

    public function createTranslationRequest()
    {
        wp_send_json(
            $this->metaboxService->createTranslationRequest(
                $_POST['postId'],
                $_POST['sourceLanguage'],
                $_POST['targetLanguages'],
                $_POST['projectId'],
                $_POST['deadline'],
                $_POST['comment'] ?? NULL
            )
        );
    }

    public function getTranslations()
    {
        wp_send_json(
            $this->metaboxService->getTranslations(
                $_POST['postIds'] ?? NULL,
                $_POST['translationRequestId'] ?? NULL
            )
        );
    }

    public function removeLanguageFromTranslationRequest()
    {
        wp_send_json(
            $this->metaboxService->removeLanguageFromTranslationRequest($_POST['postId'], $_POST['language'])
        );
    }

    public function removeTranslationRequest()
    {
        wp_send_json(
            $this->metaboxService->removeTranslationRequest($_POST['trId'])
        );
    }

    public function addLanguageToTranslationRequest()
    {
        wp_send_json(
            $this->metaboxService->addLanguageToTranslationRequest(
                $_POST['postId'],
                $_POST['translationRequestId'],
                $_POST['language']
            )
        );
    }

    public function removePostFromTranslationRequest()
    {
        wp_send_json(
            $this->metaboxService->removePostFromTranslationRequest(
                $_POST['postId'],
                $_POST['translationRequestId']
            )
        );
    }

    public function updateSourceContentAjaxAction()
    {
        wp_send_json(
            $this->metaboxService->updateSourceContent(
                $_POST['postIds'],
                $_POST['translationRequestId']
            )
        );
    }
}
