jQuery(document).ready(function ($) {
    const
        defaultErrorMessage = 'Unexpected error. Check the error log.',
        postIds = $('#smartcat-post-id').val(),
        sourceLanguage = $('#smartcat-source-language').val(),
        translationRequestId = $('#smartcat-tr-id').val(),
        languages = $('.smartcat-language'),
        languagesInTranslationRequest = $('.smartcat-language-with-tr'),
        projectsSelector = $('#smartcat-projects-list'),
        deadlineInput = $('#smartcat-deadline-input'),
        commentInput = $('#smartcat-comment-input'),
        sendToSmartcatButton = $('#send-to-smartcat-button'),
        getTranslationsButton = $('#smartcat-get-translations'),
        updateSourceContentButton = $('#update-source-content-button'),
        removeTranslationRequestButton = $('.smartcat-delete-tr-button'),
        getTranslationsForPostButton = $('.smartcat-get-translations-action'),
        errorNotice = $('#smarcat-notice-error'),
        successNotice = $('#smarcat-notice-success'),
        warnNotice = $('#smarcat-notice-warn'),
        infoNotice = $('#smarcat-notice-info'),
        popup = $('.smartcat__popup--wrapper'),
        removePostFromTrButton = $('.smartcat-remove-post-action')

    // -- Send to Smartcat --

    // project selector event
    projectsSelector.on('change', projectSelectorListener)

    // project selector listener
    function projectSelectorListener(hasParentEvent = false) {
        const selectedProject = getSelectedProject()

        if (selectedProject.val() === 'new' && getSelectedLanguageCodes().length === 0) {
            disable(sendToSmartcatButton)
            return
        }

        if (selectedProject.val() !== 'new') {
            const projectLanguages = JSON.parse(selectedProject.attr('target-languages'))
            getLanguages().each(function () {
                let language = $(this)
                if (projectLanguages.includes(language.val()) && hasParentEvent !== true) {
                    language.prop('checked', true)
                }
            })
        }

        disableOff(sendToSmartcatButton)
    }

    // languages event
    getLanguages().on('change', languagesListener)

    // languages listener
    function languagesListener() {
        projectSelectorListener(true);
    }

    // deadline input event
    deadlineInput.on('change', deadlineListener)

    // deadline input listener
    function deadlineListener() {
        const selectedProject = getSelectedProject();
        if (selectedProject.attr('deadline') && deadlineInput.val()) {
            showNotice(
                'warn',
                `Project <b>${selectedProject.text()}</b> already has a deadline of <b>${new Date(selectedProject.attr('deadline')).toGMTString()}</b>.
                        After creating a translation request, it will be changed to the current one.`,
                false
            );
        } else {
            hideAllNotices();
        }
    }

    // send to Smartcat button event
    sendToSmartcatButton.on('click', sendToSmartcat)

    // send to Smartcat button action/listener
    function sendToSmartcat() {
        buttonLoadState(sendToSmartcatButton)

        const data = {
            action: 'smartcat_create_translation_request',
            postId: postIds,
            sourceLanguage: sourceLanguage,
            targetLanguages: getSelectedLanguageCodes(),
            projectId: getSelectedProjectId() === 'new' ? null : getSelectedProjectId(),
            deadline: deadlineInput.val(),
            comment: commentInput.val()
        };

        jQuery.ajax({
            type: 'POST',
            url: ajaxurl,
            data: data,
            success: function (data) {
                if (data.status === 'failed') {
                    showNotice('error', data.message)
                    buttonNormalState(sendToSmartcatButton)
                    return;
                }

                showNotice('success', `Translation request successfully created`)

                setTimeout(function () {
                    if (document.location.href.includes('smartcat-wpml-create-translation-request')) {
                        document.location.href = '/wp-admin/admin.php?page=smartcat-wpml-dashboard'
                    } else {
                        document.location.reload(true)
                    }
                }, 1000);

                buttonNormalState(sendToSmartcatButton)
            },
            error: function () {
                showNotice('error', defaultErrorMessage)
                buttonNormalState(sendToSmartcatButton)
            }
        });
    }

    // -- Languages change --

    // languages change
    languagesInTranslationRequest.on('change', function () {
        const inTranslationRequest = $(this).attr('in-request');

        const data = {
            language: $(this).val(),
            postId: $(this).attr('post-id'),
            translationRequestId: translationRequestId
        }

        if (inTranslationRequest === 'true' && !$(this).is('checked')) {
            $(this).prop('checked', true);
            showPopup(`Do you want to remove <span class="smartcat__selection">${jQuery(this).attr('language-name')}</span> language from an
                already published translation request?`, 'removeLanguage', data)
        } else {
            $(this).prop('checked', false);
            showPopup(`Do you want to add <span class="smartcat__selection">${jQuery(this).attr('language-name')}</span> language 
            to an already published translation request?`, 'addLanguage', data)
        }
    })

    // remove language action
    function removeLanguage() {
        const popupData = getPopupData();

        const data = {
            action: 'smartcat_remove_language',
            postId: popupData.postId,
            language: popupData.language,
        };

        jQuery.ajax({
            type: 'POST',
            url: ajaxurl,
            data: data,
            success: function (data) {
                hidePopup();
                showNotice('info', 'Language removed')
                setTimeout(function () {
                    document.location.reload(true)
                }, 1000);
            },
            error: function () {
                hidePopup();
                showNotice('error', defaultErrorMessage);
            }
        });
    }

    // add language action
    function addLanguage() {
        const popupData = getPopupData();

        const data = {
            action: 'smartcat_add_language_to_translation_request',
            postId: popupData.postId,
            translationRequestId: popupData.translationRequestId,
            language: popupData.language,
        };

        jQuery.ajax({
            type: 'POST',
            url: ajaxurl,
            data: data,
            success: function (data) {
                if (data.status === 'failed') {
                    hidePopup()
                    showNotice('error', data.message)
                    return;
                }

                hidePopup()
                showNotice('success', 'Language added')

                setTimeout(function () {
                    document.location.reload(true)
                }, 1000);
            },
            error: function () {
                hidePopup();
                showNotice('error', defaultErrorMessage);
            }
        });
    }

    // -- Get from Smartcat --

    getTranslationsButton.on('click', getTranslations)

    function getTranslations(e, cPostIds = false, cTranslationRequestId = false) {
        buttonLoadState(getTranslationsButton)

        const data = {
            action: 'smartcat_get_translations',
            postIds: !cPostIds ? postIds : cPostIds,
            translationRequestId: !cTranslationRequestId ? translationRequestId : cTranslationRequestId
        };

        jQuery.ajax({
            type: 'POST',
            url: ajaxurl,
            data: data,
            success: function (data) {
                if (data.status === 'failed') {
                    showNotice('error', data.message)
                    buttonNormalState(getTranslationsButton)
                    return;
                }

                showNotice('success', `Translations successfully imported into WordPress`)
                buttonNormalState(getTranslationsButton)

                if (cTranslationRequestId) {
                    $(`#smartcat-actions-${cTranslationRequestId}`).show(0)
                    $(`#smartcat-spin-${cTranslationRequestId}`).hide(0)
                    $(`#smartcat-actions-${cPostIds}`).show(0)
                    $(`#smartcat-dropdown-menu-${cPostIds}`).show(0)
                    $(`#smartcat-spin-${cPostIds}`).hide(0)
                }
            },
            error: function () {
                showNotice('error', defaultErrorMessage)
                buttonNormalState(getTranslationsButton)

                if (cTranslationRequestId) {
                    $(`#smartcat-actions-${cTranslationRequestId}`).show(0)
                    $(`#smartcat-spin-${cTranslationRequestId}`).hide(0)
                    $(`#smartcat-dropdown-menu-${cPostIds}`).show(0)
                    $(`#smartcat-actions-${cPostIds}`).show(0)
                    $(`#smartcat-spin-${cPostIds}`).hide(0)
                }
            }
        });
    }

    // -- Update source content

    // Update source content event
    updateSourceContentButton.on('click', updateSourceContent)

    function updateSourceContent(e, cPostIds = false, cTranslationRequestId = false) {
        buttonLoadState(updateSourceContentButton)

        const data = {
            action: 'smartcat_update_source_content',
            postIds: !cPostIds ? postIds : cPostIds,
            translationRequestId: !cTranslationRequestId ? translationRequestId : cTranslationRequestId
        };

        jQuery.ajax({
            type: 'POST',
            url: ajaxurl,
            data: data,
            success: function (data) {
                if (data.status === 'failed') {
                    showNotice('error', data.message)
                    buttonNormalState(updateSourceContentButton)
                    return;
                }

                showNotice('success', `Source content successfully updated in Smartcat`)
                buttonNormalState(updateSourceContentButton)
            },
            error: function () {
                showNotice('error', defaultErrorMessage)
                buttonNormalState(updateSourceContentButton)
            }
        });
    }

    // -- Dashboard --

    removeTranslationRequestButton.on('click', function () {
        showPopup(`Do you want to delete an entire translation request?`, 'removeTranslationRequest', {
            translationRequestId: $(this).attr('smartcat-tr-id').trim()
        })
    })

    function removeTranslationRequest() {
        const data = {
            action: 'smartcat_remove_translation_request',
            trId: getPopupData().translationRequestId,
        };

        jQuery.ajax({
            type: 'POST',
            url: ajaxurl,
            data: data,
            success: function (data) {
                document.location.reload(true)
            },
            error: function () {
                showNotice('error', defaultErrorMessage)
                hidePopup()
            }
        });
    }

    $('.smartcat-get-translations-from-dashboard').on('click', function () {
        const trId = $(this).attr('smartcat-tr-id')
        $(`#smartcat-actions-${trId}`).hide(0)
        $(`#smartcat-spin-${trId}`).show(0)

        getTranslations(this, '', trId)
    })

    // -- Translation request details

    // Remove post from TR event
    removePostFromTrButton.on('click', function (e) {
        e.preventDefault()
        showPopup(`Are you sure you want to remove this article from the translation request?`, 'removePostFromTR', {
            translationRequestId: translationRequestId,
            postId: $(this).attr('post-id')
        })
    })

    // Remove post from TR listener
    function removePostFromTR() {
        const popupData = getPopupData();

        const data = {
            action: 'smartcat_remove_post_from_translation_request',
            postId: popupData.postId,
            translationRequestId: popupData.translationRequestId
        };

        jQuery.ajax({
            type: 'POST',
            url: ajaxurl,
            data: data,
            success: function (data) {
                document.location.reload(true)
            },
            error: function () {
                showNotice('error', defaultErrorMessage)
                buttonNormalState(getTranslationsButton)
            }
        });
    }

    getTranslationsForPostButton.on('click', function (e) {
        e.preventDefault()
        const postId = $(this).attr('post-id');
        $(`#smartcat-actions-${postId}`).hide(0)
        $(`#smartcat-dropdown-menu-${postId}`).hide(0)
        $(`#smartcat-spin-${postId}`).show(0)
        getTranslations(e, postId, translationRequestId)
    })

    // -- Popup --

    popup.find('.confirm').on('click', handlePopupConfirmButton);
    popup.find('.cancel').on('click', hidePopup);

    // -- Logs page --

    $('.smartcat-show-event-data').on('click', function (event) {
        event.preventDefault();
        $('#smartcat-logs-dialog').html($(this).find('.data').html());
        $('#smartcat-logs-dialog').dialog();
    })


    // -- Settings --

    function makeSecret(length) {
        let result = [];
        let characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
        let charactersLength = characters.length;
        for (let i = 0; i < length; i++) {
            result.push(characters.charAt(Math.floor(Math.random() *
                charactersLength)));
        }
        return result.join('');
    }

    $('#generate').click(function () {
        const secret = makeSecret(30);
        $('#api-secret').val(secret);
        $('#api-secret-full').val(secret);
    })

    $('#copy-smartcat-secret').click(function () {
        let $temp = $("<input>");
        $("body").append($temp);
        $temp.val($("#api-secret-full").val()).select();
        document.execCommand("copy");
        $temp.remove();
        alert("Secret key copied to clipboard")
    })

    // helpers

    function hideAllNotices() {
        errorNotice.fadeIn(0, function () {
            errorNotice.fadeOut(0);
        });
        successNotice.fadeIn(0, function () {
            successNotice.fadeOut(0);
        });
        warnNotice.fadeIn(0, function () {
            warnNotice.fadeOut(0);
        });
        infoNotice.fadeIn(0, function () {
            infoNotice.fadeOut(0);
        });
    }

    function showNotice(type = 'info', message = '', hideNotices = false) {
        if (hideNotices) {
            hideAllNotices();
        }
        switch (type) {
            case 'info':
                infoNotice.html(message);
                infoNotice.fadeOut(100, function () {
                    infoNotice.fadeIn(100);
                });
                break;
            case 'success':
                successNotice.html(message);
                successNotice.fadeOut(100, function () {
                    successNotice.fadeIn(100);
                });
                break;
            case 'error':
                errorNotice.html(message);
                errorNotice.fadeOut(100, function () {
                    errorNotice.fadeIn(100);
                });
                break;
            case 'warn':
                warnNotice.html(message);
                warnNotice.fadeOut(100, function () {
                    warnNotice.fadeIn(100);
                });
                break;
        }
    }

    function getSelectedProject() {
        return projectsSelector.find(':checked');
    }

    function getSelectedProjectId() {
        return getSelectedProject().val();
    }

    function getSelectedLanguageCodes() {
        let selectedLanguages = [];
        getSelectedLanguages().each(function () {
            selectedLanguages.push($(this).val());
        });
        return selectedLanguages;
    }

    function getSelectedLanguages() {
        return $('.smartcat-language:checked');
    }

    function getLanguages() {
        return $('.smartcat-language')
    }

    function disable(el) {
        el.prop('disabled', true)
    }

    function disableOff(el) {
        el.prop('disabled', false)
    }

    function buttonNormalState(button) {
        button.prop('disabled', false);
        button.find('.dashicons').hide();
    }

    function buttonLoadState(button) {
        button.prop('disabled', true);
        button.find('.dashicons').show();
    }

    function showPopup(message, action, data) {
        popup.find('.smartcat__popup--title').html(message);
        popup.find('.data').text(JSON.stringify(data));
        popup.fadeOut(100, function () {
            popup.fadeIn(100);
        });
        popup.find('.confirm').attr('action', action);
    }

    function hidePopup() {
        popup.fadeIn(100, function () {
            popup.fadeOut(100);
        });
        $(this).prop('disabled', false);
        $(this).find('.dashicons').hide();
    }

    function getPopupData() {
        return JSON.parse(popup.find('.data').text());
    }

    function handlePopupConfirmButton() {
        $(this).prop('disabled', true);
        $(this).find('.dashicons').show();
        switch ($(this).attr('action')) {
            case 'removeLanguage':
                removeLanguage();
                break;
            case 'addLanguage':
                addLanguage();
                break;
            case 'removeTranslationRequest':
                removeTranslationRequest();
                break;
            case 'removePostFromTR':
                removePostFromTR();
                break;
        }
    }

})