<?php

namespace Smartcat\Includes\Services\Plugin;

class SmartcatMigrations
{
    /**
     * @var \wpdb
     */
    private $wpdb;

    public function __construct()
    {
        global $wpdb;
        $this->wpdb = $wpdb;
    }

    public function run()
    {
        $this->logs_table();
        $this->smartcatDocumentsTable();
        $this->addCommentFiledToDocumentsTable();
        $this->addIActiveFiledToDocumentsTable();
    }

    public function drop()
    {
        $this->wpdb->query("DROP TABLE {$this->wpdb->prefix}" . SMARTCAT_LOGS_TABLE_NAME);
        $this->wpdb->query("DROP TABLE {$this->wpdb->prefix}" . SMARTCAT_DOCUMENTS_TABLE_NAME);
    }

    private function logs_table()
    {
        $tableName = $this->wpdb->prefix . SMARTCAT_LOGS_TABLE_NAME;

        if ($this->wpdb->get_var("SHOW TABLES LIKE '$tableName'") != $tableName) {
            $SQL = "create table $tableName
                    (
                        id bigint(24) auto_increment,
                        type varchar(25) default NULL,
                        message text default NULL,
                        data text default NULL,
                        exception text default NULL,
                        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
                            primary key (id)
                    );
                    ";
            $this->wpdb->query($SQL);
        }
    }

    private function smartcatDocumentsTable()
    {
        $tableName = $this->wpdb->prefix . SMARTCAT_DOCUMENTS_TABLE_NAME;

        if ($this->wpdb->get_var("SHOW TABLES LIKE '$tableName'") != $tableName) {
            $tableSchema = "CREATE TABLE `$tableName`
                (
                    `translation_request_id`  varchar(255) null,
                    `post_id`              bigint unsigned null,
                    `translated_post_id`   bigint unsigned null,
                    `smartcat_document_id` varchar(255) null,
                    `smartcat_project_name` varchar(255) null,
                    `smartcat_project_id`  varchar(255) null,
                    `lang`                 varchar(255) null,
                    `translation_progress` varchar(255) null,
                    `created_at`           timestamp null
                ) default character set utf8mb4
                  collate 'utf8mb4_unicode_ci';";

            $this->wpdb->query($tableSchema);
            $postIdRelation = "alter table `$tableName` add constraint `$tableName" . "_post_id_foreign` foreign key (`post_id`) references `wp_posts` (`ID`) on delete cascade;";
            $this->wpdb->query($postIdRelation);
            $translatedPostIdRelation = "alter table `$tableName` add constraint `$tableName" . "_translated_post_id_foreign` foreign key (`translated_post_id`) references `wp_posts` (`ID`) on delete cascade;";
            $this->wpdb->query($translatedPostIdRelation);
        }
    }

    private function addCommentFiledToDocumentsTable()
    {
        $tableName = $this->wpdb->prefix . SMARTCAT_DOCUMENTS_TABLE_NAME;
        $columnName = 'comment';

        $row = $this->wpdb->get_results(
            "SHOW COLUMNS FROM `$tableName` LIKE '$columnName'"
        );

        if (empty($row)) {
            $this->wpdb->query("ALTER TABLE $tableName ADD $columnName text default NULL AFTER `translation_progress`");
        }
    }

    private function addIActiveFiledToDocumentsTable()
    {
        $tableName = $this->wpdb->prefix . SMARTCAT_DOCUMENTS_TABLE_NAME;
        $columnName = 'is_active';

        $row = $this->wpdb->get_results(
            "SHOW COLUMNS FROM `$tableName` LIKE '$columnName'"
        );

        if (empty($row)) {
            $this->wpdb->query("ALTER TABLE $tableName ADD $columnName int(1) default 1 AFTER `comment`");
        }
    }
}