<?php

namespace Smartcat\Includes;

use Smartcat\Includes\Plugin\SmartcatPluginLoader;
use Smartcat\Includes\Plugin\SmartcatPluginMultilingual;
use Smartcat\Publicly\SmartcatPublic;
use SmartcatAdmin;
use function Sodium\add;

class SmartcatWpml
{
    protected $loader;
    protected $pluginName;
    protected $version;
    protected $admin;

    public function __construct()
    {
        $this->version = SMARTCAT_WPML_VERSION;
        $this->pluginName = 'smartcat-wpml';

        $this->loadDependencies();
        $this->setLocale();
        $this->defineAdminHooks();
        $this->definePublicHooks();
    }

    private function loadDependencies()
    {
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/Plugin/SmartcatPluginLoader.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/Plugin/SmartcatPluginMultilingual.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/SmartcatAdmin.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'public/SmartcatPublic.php';
        $this->loader = new SmartcatPluginLoader();
    }

    private function setLocale()
    {
        $pluginMultilingual = new SmartcatPluginMultilingual();
        $this->loader->add_action('plugins_loaded', $pluginMultilingual, 'loadPluginTextdomain');
    }

    private function defineAdminHooks()
    {
        $this->admin = new SmartcatAdmin($this->getPluginName(), $this->getVersion());

        $this->loader->add_action('admin_enqueue_scripts', $this->admin, 'enqueue_styles');
        $this->loader->add_action('admin_enqueue_scripts', $this->admin, 'enqueue_scripts');

        // Settings -> Smartcat Integration for WPML
        $this->loader->add_action('admin_menu', $this->admin, 'addPluginAdminMenu');

        $pluginBasename = plugin_basename(plugin_dir_path(__DIR__) . $this->pluginName . '.php');

        $this->loader->add_filter('plugin_action_links_' . $pluginBasename, $this->admin, 'addActionLinks');
        $this->loader->add_action('add_meta_boxes', $this->admin, 'registerSmartcatMetabox');

        $wpmlPostTypes = smartcat_post_type()->getWpmlPostTypes();

        foreach ($wpmlPostTypes as $key => $type) {
            $this->loader->add_filter("bulk_actions-edit-$key", $this->admin, 'addBulkActionToPostsPage');
        }

        foreach ($wpmlPostTypes as $key => $type) {
            $this->loader->add_filter("handle_bulk_actions-edit-$key", $this->admin, 'handleBulkActionSmartcatCreateTR', 10, 3);
        }

        $this->loader->add_action('delete_post', $this->admin, 'deleteTranslation', 10, 1);

        $this->loader->add_action('plugins_loaded', $this->admin, 'checkOrUpdateMigrations');

        $this->registerAdminActions();
        $this->notices();
    }

    private function registerAdminActions()
    {
        $this->loader->add_action("admin_post_smartcat_update_options", $this->admin, "smartcatUpdateOptions");
        $this->loader->add_action("admin_post_smartcat_logout", $this->admin, "smartcatLogout");
        $this->loader->add_action("admin_post_smartcat_log_in", $this->admin, "logInToSmartcat");
        $this->loader->add_action('admin_post_smartcat_auth_host', $this->admin, 'updateDebugSettings');

        $this->loader->add_action('wp_ajax_smartcat_create_translation_request', $this->admin, 'createTranslationRequest');
        $this->loader->add_action('wp_ajax_smartcat_get_translations', $this->admin, 'getTranslations');
        $this->loader->add_action('wp_ajax_smartcat_remove_language', $this->admin, 'removeLanguageFromTranslationRequest');
        $this->loader->add_action('wp_ajax_smartcat_remove_translation_request', $this->admin, 'removeTranslationRequest');
        $this->loader->add_action('wp_ajax_smartcat_add_language_to_translation_request', $this->admin, 'addLanguageToTranslationRequest');
        $this->loader->add_action('wp_ajax_smartcat_remove_post_from_translation_request', $this->admin, 'removePostFromTranslationRequest');
        $this->loader->add_action('wp_ajax_smartcat_update_source_content', $this->admin, 'updateSourceContentAjaxAction');
    }

    private function definePublicHooks()
    {
        $pluginPublic = new SmartcatPublic();
        $this->loader->add_action('rest_api_init', $pluginPublic, 'routes');
    }

    public function run()
    {
        $this->loader->run();
    }

    public function getPluginName(): string
    {
        return $this->pluginName;
    }

    public function getLoader()
    {
        return $this->loader;
    }

    public function getVersion(): string
    {
        return $this->version;
    }

    private function notices()
    {
        $this->loader->add_action('admin_notices', $this->admin, 'displayPluginAdminNotices');

        if (!function_exists('icl_object_id')) {
            $this->loader->add_action('admin_notices', $this->admin, 'displayWpmlNotInstalledNotice');
        }

        if (empty(get_option("permalink_structure"))) {
            $this->loader->add_action('admin_notices', $this->admin, 'displayFriendlyUrlNotice');
        }
    }
}
