<?php

namespace Smartcat\Includes\Views;

use Smartcat\Includes\Plugin\SmartcatPluginMultilingual as i18n;
use Smartcat\Includes\Tables\SmartcatLanguages;
use Smartcat\Includes\Tables\SmartcatLanguagesWithTranslations;

class SmartcatComponents
{
    public function getTranslationsButton()
    {
        ?>
        <button id="smartcat-get-translations" class="button button-secondary smartcat-button">
            <span class="dashicons dashicons-update"></span>
            <?php i18n::e('Get from Smartcat'); ?>
        </button>
        <?php
    }

    public function projectLink($projectId, $projectName)
    {
        ?>
        <div style="display:flex; align-items: center; margin-bottom: 10px;">
            <input type="hidden" id="smartcat-project-id" value="<?php echo $projectId ?>">
            <?php i18n::e('Smartcat project: '); ?>
            <a style="display:block; margin: 0 0 0 3px" target="_blank" href="<?php echo smartcat_api()::getAuthHost() ?>/projects/<?php echo $projectId ?>/files">
                <?php echo $projectName ?>
            </a>
        </div>
        <?php
    }

    public function projectDeadline($deadline)
    {
        ?>
        <p><?php i18n::e('Deadline'); ?>: <i><?php
                $deadline = isset($deadline) ? new \DateTime($deadline) : NULL;
                echo !empty($deadline) ? $deadline->format('Y/m/d H:i:s') : i18n::_e('Not set')
                ?></i></p>
        <?php
    }

    public function commentInput()
    {
        ?>
        <label class="wp-caption-text" style="display: block;margin-top: 10px;" for="smartcat-comment-input">
            <?php i18n::e('Comment'); ?>
        </label>
        <textarea
            placeholder="<?php i18n::e('Example: Read the following style guide before translat...'); ?>"
            id="smartcat-comment-input"
            style="display: block; margin: 10px 0; width: 100%;"
        ></textarea>
        <?php
    }

    public function sendToSmartcatButton()
    {
        ?>
        <button id="send-to-smartcat-button" style="margin-top: 10px;" class="button button-primary smartcat-button" disabled>
            <span class="dashicons dashicons-update"></span>
            <?php i18n::e('Send to Smartcat'); ?>
        </button>
        <?php
    }

    public function updateSourceButton()
    {
        ?>
        <button id="update-source-content-button" class="button button-primary smartcat-button">
            <span class="dashicons dashicons-update"></span>
            <?php i18n::e('Update source content'); ?>
        </button>
        <?php
    }

    public function deadlineInput()
    {
        ?>
        <label class="wp-caption-text" style="display: block;margin-top: 10px;" for="smartcat-deadline-input">
            <?php i18n::e('Deadline'); ?>
        </label>
        <input
            type="datetime-local"
            id="smartcat-deadline-input"
            style="display: block; margin: 10px 0;"
        >
        <?php
    }

    public function projectsSelector($sourceLanguageCode)
    {
        ?>
        <label class="wp-caption-text" style="display: block; margin-top: 10px;" for="">
            <?php i18n::e('Smartcat project'); ?>
        </label>
        <?php
        $projects = smartcat_api()->getAccountProjects();
        if (is_wp_error($projects)) {
            $projects->showError();
        } else {
            ?>
            <select id="smartcat-projects-list" style="margin: 10px 0; width: 100%">
                <option value="new" selected>
                    <?php i18n::e('New project'); ?>
                </option>
                <?php
                $projects = array_filter($projects, function ($p) use ($sourceLanguageCode) {
                    return $p['sourceLanguage'] === $sourceLanguageCode;
                });
                foreach ($projects as $project) {
                    ?>
                    <option
                        source-language="<?php echo $project['sourceLanguage'] ?>"
                        target-languages='<?php echo json_encode($project['targetLanguages']) ?>'
                        deadline="<?php echo $project['deadline'] ?? '' ?>"
                        value="<?php echo $project['id'] ?>"
                    ><?php echo $project['name']; ?></option>
                    <?php
                }
                ?>
            </select>
            <?php
        }
    }

    public function languagesTableWithTranslations($postId)
    {
        ?>
        <label class="wp-caption-text" for="source_language" style="display: block; margin: 10px 0;">
            <?php i18n::e('Target languages'); ?>
        </label>
        <?php
        $table = new SmartcatLanguagesWithTranslations();
        $table->setPostId($postId);
        $table->prepare_items();
        $table->display();
    }

    public function languagesTable()
    {
        ?>
        <label class="wp-caption-text" for="source_language" style="display: block; margin: 10px 0;">
            <?php i18n::e('Target languages'); ?>
        </label>
        <?php
        $table = new SmartcatLanguages();
        $table->prepare_items();
        $table->display();
    }

    public function hiddenInputs($sourceLanguageCode, $postId = NULL, $translationRequestId = NULL)
    {
        ?>
        <input type="hidden" id="smartcat-post-id" value="<?php echo $postId ?>">
        <input type="hidden" id="smartcat-source-language" value="<?php echo $sourceLanguageCode ?>">
        <input type="hidden" id="smartcat-tr-id" value="<?php echo $translationRequestId ?>">
        <?php
    }

    public function sourceLanguage(string $sourceLanguageName)
    {
        ?>
        <label class="wp-caption-text" for="source_language">
            <?php i18n::e('Source language'); ?>: <b><?php echo $sourceLanguageName ?></b>
        </label>
        <?php
    }

    public function authForm()
    {
        ?>
        <form action="<?php echo esc_url(admin_url('admin-post.php')); ?>" method="post">
            <input type="hidden" name="action" value="smartcat_log_in">
            <button type="submit" style="margin-top: 10px;" id="log-in-button" class="button button-secondary"><?php i18n::e('Log in with Smartcat'); ?></button>
        </form>
        <?php
    }

    public function notices()
    {
        ?>
        <p id="smarcat-notice-warn" class="notice notice-warning" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <p id="smarcat-notice-success" class="notice notice-success" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <p id="smarcat-notice-info" class="notice notice-info" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <p id="smarcat-notice-error" class="notice notice-error" style="display: none; margin: 10px 0; padding: 5px 10px;"></p>
        <?php
    }

    public function popup()
    {
        ?>
        <div class="smartcat__popup--wrapper">
            <div class="smartcat__popup--body">
                <div class="data" style="display: none"></div>
                <p class="smartcat__popup--title"></p>
                <div class="smartcat__popup--buttons">
                    <button class="button cancel"><?php i18n::e('Cancel'); ?></button>
                    <button class="button button-primary confirm smartcat__button">
                        <span class="dashicons dashicons-update"></span>
                        <?php i18n::e('Yes'); ?>
                    </button>
                </div>
            </div>
        </div>
        <?php
    }

    public function startWrapper($width = '100%', $classes = '')
    {
        echo '<div class="smartcat__wrapper ' . $classes . ' " style="width: ' . $width . ';">';
    }

    public function endWrapper()
    {
        echo '</div>';
    }

    public function startButtonGroup()
    {
        ?>
        <div class="smartcat__button--group">
        <?php
    }

    public function endButtonGroup()
    {
        ?>
        </div>
        <?php
    }

    public function title(string $text = '')
    {
        ?>
        <h2 class="smartcat__title"><?php i18n::e($text) ?></h2>
        <?php
    }
}